@@ -1,16 +1,5 @@
 // Copyright The OpenTelemetry Authors
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+// SPDX-License-Identifier: Apache-2.0
 
 package otelmongo // import "go.opentelemetry.io/contrib/instrumentation/go.mongodb.org/mongo-driver/mongo/otelmongo"
 
@@ -27,7 +16,6 @@ import (
 	"go.opentelemetry.io/otel/trace"
 
 	"go.mongodb.org/mongo-driver/bson"
-	"go.mongodb.org/mongo-driver/bson/bsontype"
 	"go.mongodb.org/mongo-driver/event"
 )
 
@@ -107,7 +95,7 @@ func (m *monitor) Finished(evt *event.CommandFinishedEvent, err error) {
 	span.End()
 }
 
-// TODO sanitize values where possible, then reenable `db.statement` span attributes default.
+// TODO sanitize values where possible, then re-enable `db.statement` span attributes default.
 // TODO limit maximum size.
 func sanitizeCommand(command bson.Raw) string {
 	b, _ := bson.MarshalExtJSON(command, false, false)
@@ -125,7 +113,7 @@ func extractCollection(evt *event.CommandStartedEvent) (string, error) {
 	}
 	if key, err := elt.KeyErr(); err == nil && key == evt.CommandName {
 		var v bson.RawValue
-		if v, err = elt.ValueErr(); err != nil || v.Type != bsontype.String {
+		if v, err = elt.ValueErr(); err != nil || v.Type != bson.TypeString {
 			return "", err
 		}
 		return v.StringValue(), nil
